# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/torchserve_client',
                'doc_host': 'https://Ankur-singh.github.io',
                'git_url': 'https://github.com/Ankur-singh/torchserve_client',
                'lib_path': 'torchserve_client'},
  'syms': { 'torchserve_client.base': { 'torchserve_client.base.BaseClient': ('base.html#baseclient', 'torchserve_client/base.py'),
                                        'torchserve_client.base.BaseClient.__init__': ( 'base.html#baseclient.__init__',
                                                                                        'torchserve_client/base.py'),
                                        'torchserve_client.base.BaseClient.__repr__': ( 'base.html#baseclient.__repr__',
                                                                                        'torchserve_client/base.py'),
                                        'torchserve_client.base.BaseClient._filter_none_values': ( 'base.html#baseclient._filter_none_values',
                                                                                                   'torchserve_client/base.py'),
                                        'torchserve_client.base.BaseClient._make_request': ( 'base.html#baseclient._make_request',
                                                                                             'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient': ( 'base.html#inferenceclient',
                                                                                    'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient.__init__': ( 'base.html#inferenceclient.__init__',
                                                                                             'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient.api_description': ( 'base.html#inferenceclient.api_description',
                                                                                                    'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient.explaination': ( 'base.html#inferenceclient.explaination',
                                                                                                 'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient.health_check': ( 'base.html#inferenceclient.health_check',
                                                                                                 'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient.prediction': ( 'base.html#inferenceclient.prediction',
                                                                                               'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient': ( 'base.html#managementclient',
                                                                                     'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.__init__': ( 'base.html#managementclient.__init__',
                                                                                              'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.api_description': ( 'base.html#managementclient.api_description',
                                                                                                     'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.describe_model': ( 'base.html#managementclient.describe_model',
                                                                                                    'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.list_models': ( 'base.html#managementclient.list_models',
                                                                                                 'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.register_model': ( 'base.html#managementclient.register_model',
                                                                                                    'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.scale_workers': ( 'base.html#managementclient.scale_workers',
                                                                                                   'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.set_default_version': ( 'base.html#managementclient.set_default_version',
                                                                                                         'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.unregister_model': ( 'base.html#managementclient.unregister_model',
                                                                                                      'torchserve_client/base.py')},
            'torchserve_client.core': { 'torchserve_client.core.BaseClient': ('base.html#baseclient', 'torchserve_client/core.py'),
                                        'torchserve_client.core.BaseClient.__init__': ( 'base.html#baseclient.__init__',
                                                                                        'torchserve_client/core.py'),
                                        'torchserve_client.core.BaseClient.__repr__': ( 'base.html#baseclient.__repr__',
                                                                                        'torchserve_client/core.py'),
                                        'torchserve_client.core.BaseClient._filter_none_values': ( 'base.html#baseclient._filter_none_values',
                                                                                                   'torchserve_client/core.py'),
                                        'torchserve_client.core.BaseClient._make_request': ( 'base.html#baseclient._make_request',
                                                                                             'torchserve_client/core.py')},
            'torchserve_client.inference': { 'torchserve_client.inference.InferenceClient': ( 'inference.html#inferenceclient',
                                                                                              'torchserve_client/inference.py'),
                                             'torchserve_client.inference.InferenceClient.__init__': ( 'inference.html#inferenceclient.__init__',
                                                                                                       'torchserve_client/inference.py'),
                                             'torchserve_client.inference.InferenceClient.api_description': ( 'inference.html#inferenceclient.api_description',
                                                                                                              'torchserve_client/inference.py'),
                                             'torchserve_client.inference.InferenceClient.explaination': ( 'inference.html#inferenceclient.explaination',
                                                                                                           'torchserve_client/inference.py'),
                                             'torchserve_client.inference.InferenceClient.health_check': ( 'inference.html#inferenceclient.health_check',
                                                                                                           'torchserve_client/inference.py'),
                                             'torchserve_client.inference.InferenceClient.prediction': ( 'inference.html#inferenceclient.prediction',
                                                                                                         'torchserve_client/inference.py')},
            'torchserve_client.management': { 'torchserve_client.management.ManagementClient': ( 'management.html#managementclient',
                                                                                                 'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.__init__': ( 'management.html#managementclient.__init__',
                                                                                                          'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.api_description': ( 'management.html#managementclient.api_description',
                                                                                                                 'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.describe_model': ( 'management.html#managementclient.describe_model',
                                                                                                                'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.list_models': ( 'management.html#managementclient.list_models',
                                                                                                             'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.register_model': ( 'management.html#managementclient.register_model',
                                                                                                                'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.scale_workers': ( 'management.html#managementclient.scale_workers',
                                                                                                               'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.set_default_version': ( 'management.html#managementclient.set_default_version',
                                                                                                                     'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.unregister_model': ( 'management.html#managementclient.unregister_model',
                                                                                                                  'torchserve_client/management.py')}}}
