__version__ = "0.0.1"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_init.ipynb.

# %% auto 0
__all__ = ['TorchServeClient']

# %% ../nbs/01_init.ipynb 2
from .base import ManagementClient, InferenceClient

# %% ../nbs/01_init.ipynb 3
class TorchServeClient:
    def __init__(self, base_url=None, management_port=8081, inference_port=8080):
        self.management = ManagementClient(base_url, management_port)
        self.inference = InferenceClient(base_url, inference_port)

    def __repr__(self):
        url = self.management.base_url.rsplit(":", 1)[0]
        return f"TorchServeClient(base_url={url}, management_port={self.management.port}, inference_port={self.inference.port})"
